@@ -1,4 +1,6 @@
 from .change_key import change_key
 from .check_key import check_key
-from .make_key import make_key
+from .copy_key import copy_key
 from .get_keys import get_keys
+from .make_key import make_key
+from .remove_key import remove_key
